<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl"
    xmlns:mappull="http://dita-ot.sourceforge.net/ns/200704/mappull"
    xmlns:dita-ot="http://dita-ot.sourceforge.net/ns/201007/dita-ot" exclude-result-prefixes="xs xd"
    version="2.0">

<!--The purpose of this XSLT is used to propagate at the topic level the metadata declared in othermeta elements-->
  <!--The purpose of this XSLT is used to propagate at the topic level the metadata declared in othermeta elements-->
    
<!-- map URL -->
<xsl:param name="input.map.url" as="xs:string?"/>

<!-- map document  -->
<xsl:variable name="mapDoc" as="document-node()?">
    <xsl:apply-templates select="document($input.map.url)" mode="normalize-map"/>
</xsl:variable>

<!-- Root template -->
<xsl:template match="/">
    <!-- Print the value of input.map.url for debugging -->
    <xsl:message>OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO</xsl:message>
    <xsl:message>Value of input.map.url: <xsl:value-of select="$mapDoc"/></xsl:message>

    <!-- Check if the document is loaded -->
    <xsl:if test="$mapDoc">
        <!-- Print information about the loaded document -->
        <xsl:message>Document loaded successfully from <xsl:value-of select="document-uri($mapDoc)"/></xsl:message>
        <xsl:message>Number of nodes in the document: <xsl:value-of select="count($mapDoc//*)"/></xsl:message>
    </xsl:if>

    <!-- If the document fails to load, print an error message -->
    <xsl:if test="not($mapDoc)">
        <xsl:message>Error loading the document at <xsl:value-of select="$mapDoc"/>.</xsl:message>
    </xsl:if>

    <!-- If input.map.url is not set, print an error message -->
    <xsl:if test="not($input.map.url)">
        <xsl:message>Error: input.map.url parameter is not set.</xsl:message>
    </xsl:if>

    <!-- Apply further processing here -->
    <xsl:apply-templates/>
</xsl:template>


<xsl:template name="chapterHead">
    <xsl:apply-templates select="." mode="chapterHead"/>
</xsl:template>

<xsl:template match="*" mode="chapterHead">
    <head><xsl:value-of select="$newline"/>
        <!-- initial meta information -->
        <xsl:call-template name="generateCharset"/>   <!-- Set the character set to UTF-8 -->
        <xsl:call-template name="generateDefaultCopyright"/> <!-- Generate a default copyright, if needed -->
        <xsl:call-template name="generateDefaultMeta"/> <!-- Standard meta for security, robots, etc -->
        <xsl:call-template name="getMeta"/>           <!-- Process metadata from topic prolog -->
        <!-- call metadata from the map, and place it in the head of the topic -->

        <xsl:message>XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX <xsl:value-of select="$mapDoc"/></xsl:message>

        <xsl:apply-templates select="$mapDoc//*[contains(@class, ' topic/othermeta ')]" mode="inheritanceOthermeta"/>
        <xsl:call-template name="copyright"/>         <!-- Generate copyright, if specified manually -->
        <xsl:call-template name="generateCssLinks"/>  <!-- Generate links to CSS files -->
        <xsl:call-template name="generateChapterTitle"/> <!-- Generate the <title> element -->
        <xsl:call-template name="gen-user-head" />    <!-- include user's XSL HEAD processing here -->
        <xsl:call-template name="gen-user-scripts" /> <!-- include user's XSL javascripts here -->
        <xsl:call-template name="gen-user-styles" />  <!-- include user's XSL style element and content here -->
        <xsl:call-template name="processHDF"/>        <!-- Add user HDF file, if specified -->
    </head>
    <xsl:value-of select="$newline"/>
</xsl:template>

<!-- Rename othermeta to meta, creates the meta -->
<xsl:template match="*[contains(@class, ' topic/othermeta ')]" mode="inheritanceOthermeta">
    <xsl:variable name="prefix">customFT:</xsl:variable>
    <xsl:element name="meta">
        <xsl:attribute name="name">
            <xsl:value-of select="concat($prefix, @name)" />
        </xsl:attribute>
        <xsl:attribute name="content" select="@content"/>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>